@@ -3,6 +3,7 @@
 #' Returns a data frame of matching postcodes.
 #'
 #' @importFrom httr GET
+#' @importFrom utils URLencode
 #'
 #' @param postcode A string. Valid UK postcode.
 #' @param limit An integer. Limits number of postcodes matches to return. Defaults to 10. Needs to be less than 100.
@@ -24,6 +25,7 @@ postcode_autocomplete <- function(postcode, limit = 10) {
   if (limit > 100) {
     stop("Please provide an integer lower than 100.")
   }
+  postcode <- URLencode(postcode)
   r <- GET(paste0("https://api.postcodes.io/postcodes/",
                   postcode, "/autocomplete", "?limit=", limit))
   r <- extract_results(r)
