@@ -3,6 +3,7 @@
 #' Submit a postcode query and receive a complete list of postcode matches and all associated postcode data.
 #'
 #' @importFrom httr GET
+#' @importFrom utils URLencode
 #'
 #' @param postcode A string. Valid UK postcode.
 #' @param limit An integer. Limits the number of matches to return. Defaults to 10. Needs to be less than 100.
@@ -25,6 +26,7 @@ postcode_query <- function(postcode, limit = 10) {
   if (limit > 100) {
     stop("Please provide an integer lower than 100.")
   }
+  postcode <- URLencode(postcode)
   r <- GET(paste0("https://api.postcodes.io/postcodes?q=",
                   postcode, "&limit=", limit))
   extract_results(r)
