@@ -6,13 +6,13 @@ test_that("scottish_postcode_lookup works as expected", {
 
   incorrect_postcode1 <- 1
   incorrect_postcode2 <- "E"
-  incorrect_postcode3 <- c("EC1Y8LX", "EX165BL")
+  incorrect_postcode3 <- "EC1Y8LX"
 
   postcode_lookup_result <- scottish_postcode_lookup("EH12NG")
 
-  expect_error(postcode_lookup(incorrect_postcode1))
-  expect_error(postcode_lookup(incorrect_postcode2))
-  expect_error(postcode_lookup(incorrect_postcode3))
+  expect_error(scottish_postcode_lookup(incorrect_postcode1))
+  expect_error(scottish_postcode_lookup(incorrect_postcode2))
+  expect_warning(scottish_postcode_lookup(incorrect_postcode3))
 
   expect_that(postcode_lookup_result, is_a("data.frame"))
 
